==> pyVersioning-0.5.0.tar.gz: pyVersioning-0.5.0/README.md <==
[![Sourcecode on GitHub](https://img.shields.io/badge/Paebbels-pyVersioning-323131.svg?logo=github&longCache=true)](https://github.com/Paebbels/pyVersioning)
[![License](https://img.shields.io/badge/Apache%20License,%202.0-bd0000.svg?longCache=true&label=code%20license&logo=Apache&logoColor=D22128)](LICENSE.md)
[![GitHub tag (latest SemVer incl. pre-release)](https://img.shields.io/github/v/tag/Paebbels/pyVersioning?logo=GitHub&include_prereleases)](https://github.com/Paebbels/pyVersioning/tags)
[![GitHub release (latest SemVer incl. including pre-releases)](https://img.shields.io/github/v/release/Paebbels/pyVersioning?logo=GitHub&include_prereleases)](https://github.com/Paebbels/pyVersioning/releases/latest)
[![GitHub release date](https://img.shields.io/github/release-date/Paebbels/pyVersioning?logo=GitHub&)](https://github.com/Paebbels/pyVersioning/releases)  
[![Travis](https://img.shields.io/travis/com/Paebbels/pyVersioning?logo=Travis)](https://travis-ci.com/Paebbels/pyVersioning)
[![PyPI](https://img.shields.io/pypi/v/pyVersioning?logo=PyPI)](https://pypi.org/project/pyVersioning/)
![PyPI - Status](https://img.shields.io/pypi/status/pyVersioning?logo=PyPI)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyVersioning?logo=PyPI)
[![Dependent repos (via libraries.io)](https://img.shields.io/librariesio/dependent-repos/pypi/pyVersioning)](https://github.com/Paebbels/pyVersioning/network/dependents)  
[![Libraries.io status for latest release](https://img.shields.io/librariesio/release/pypi/pyVersioning)](https://libraries.io/github/Paebbels/pyVersioning)
[![Requires.io](https://img.shields.io/requires/github/Paebbels/pyVersioning)](https://requires.io/github/Paebbels/pyVersioning/requirements/?branch=master)  
[![Codacy - Quality](https://api.codacy.com/project/badge/Grade/)](https://www.codacy.com/manual/Paebbels/pyVersioning)
[![Libraries.io SourceRank](https://img.shields.io/librariesio/sourcerank/pypi/pyVersioning)](https://libraries.io/github/Paebbels/pyVersioning/sourcerank)  
[![Read the Docs](https://img.shields.io/readthedocs/pyversioning)](https://pyVersioning.readthedocs.io/en/latest/)


# pyVersioning

The Python package `pyVersioning` offers a template tool to write version
information for any programming language as a source file that can be included
into the normal build flow.


## Use Cases

* Integrate version information from e.g. Git into current builds


## Supported Languages

* Any language


## Tested with...

* ANSI C
* VHDL


## Examples

* ANSI C Example
* VHDL Example


## Contributors

* [Patrick Lehmann](https://github.com/Paebbels) (Maintainer)


## License

This library is licensed under [Apache License 2.0](LICENSE.md)

-------------------------

SPDX-License-Identifier: Apache-2.0

==> pyVersioning-0.7.1.tar.gz: pyVersioning-0.7.1/README.md <==
[![Sourcecode on GitHub](https://img.shields.io/badge/Paebbels-pyVersioning-323131.svg?logo=github&longCache=true)](https://github.com/Paebbels/pyVersioning)
[![License](https://img.shields.io/badge/code%20license-Apache%20License%2C%202.0-lightgrey?logo=GitHub)](LICENSE.md)
[![GitHub tag (latest SemVer incl. pre-release)](https://img.shields.io/github/v/tag/Paebbels/pyVersioning?logo=GitHub&include_prereleases)](https://github.com/Paebbels/pyVersioning/tags)
[![GitHub release (latest SemVer incl. including pre-releases)](https://img.shields.io/github/v/release/Paebbels/pyVersioning?logo=GitHub&include_prereleases)](https://github.com/Paebbels/pyVersioning/releases/latest)
[![GitHub release date](https://img.shields.io/github/release-date/Paebbels/pyVersioning?logo=GitHub&)](https://github.com/Paebbels/pyVersioning/releases)  
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/Paebbels/pyVersioning/Test,%20Coverage%20and%20Release?label=Workflow&logo=GitHub)](https://github.com/Paebbels/pyVersioning/actions?query=workflow%3A%22Test%2C+Coverage+and+Release%22)
[![PyPI](https://img.shields.io/pypi/v/pyVersioning?logo=PyPI)](https://pypi.org/project/pyVersioning/)
![PyPI - Status](https://img.shields.io/pypi/status/pyVersioning?logo=PyPI)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyVersioning?logo=PyPI)
[![Dependent repos (via libraries.io)](https://img.shields.io/librariesio/dependent-repos/pypi/pyVersioning)](https://github.com/Paebbels/pyVersioning/network/dependents)  
[![Libraries.io status for latest release](https://img.shields.io/librariesio/release/pypi/pyVersioning)](https://libraries.io/github/Paebbels/pyVersioning)
[![Requires.io](https://img.shields.io/requires/github/Paebbels/pyVersioning)](https://requires.io/github/Paebbels/pyVersioning/requirements/?branch=master)  
[![Codacy - Quality](https://img.shields.io/codacy/grade/b63aac7ef7e34baf829f11a61574bbaf?logo=Codacy)](https://www.codacy.com/manual/Paebbels/pyVersioning)
[![Codacy - Coverage](https://img.shields.io/codacy/coverage/b63aac7ef7e34baf829f11a61574bbaf?logo=Codacy)](https://www.codacy.com/manual/Paebbels/pyVersioning)
[![Codecov - Branch Coverage](https://img.shields.io/codecov/c/github/Paebbels/pyVersioning?logo=Codecov)](https://codecov.io/gh/Paebbels/pyVersioning)
[![Libraries.io SourceRank](https://img.shields.io/librariesio/sourcerank/pypi/pyVersioning)](https://libraries.io/github/Paebbels/pyVersioning/sourcerank)  
[![Read the Docs](https://img.shields.io/readthedocs/pyversioning)](https://pyVersioning.readthedocs.io/en/latest/)


# pyVersioning

The Python package `pyVersioning` offers a template tool to write version
information for any programming language as a source file that can be included
into the normal build flow.


## Use Cases

* Integrate version information from e.g. Git into current builds


## Supported Languages

* Any language


## Tested with...

* ANSI C
* VHDL


## Examples

* ANSI C Example
* VHDL Example


## Contributors

* [Patrick Lehmann](https://github.com/Paebbels) (Maintainer)


## License

This Python package (source code) is licensed under [Apache License 2.0](LICENSE.md).

<!-- The accompanying documentation is licensed under Creative Commons - Attribution-4.0 (CC-BY 4.0). -->


-------------------------

SPDX-License-Identifier: Apache-2.0
